@@ -9,5 +9,5 @@ except ImportError:
 
 def init():
     register_xpath_extensions()
-    if ML_ENABLED:
-        signature.initialize()
+    # if ML_ENABLED:
+    #     signature.initialize()
